<?php
// include database connection file
include_once("config.php");

// Check if form is submitted for user update, then redirect to homepage after update
if (isset($_POST['update'])) {
    $id = $_POST['id_member'];
    $username = strtolower($_POST['username']);
    $jenis_cheat = $_POST['jenis_cheat'];

    // update user data using prepared statements to prevent SQL injection
    $stmt = $mysqli->prepare("UPDATE data_member SET username=?, jenis_cheat=? WHERE id_member=?");
    $stmt->bind_param("ssi", $username, $jenis_cheat, $id);
    $stmt->execute();

    // Redirect to homepage to display updated user in list
    header("Location: all-data.php");
    exit(); // Make sure to stop further script execution
}
?>

<?php
// Display selected user data based on id
// Getting id from url
$id = $_GET['id'];

// Fetch user data based on id_member using prepared statement
$stmt = $mysqli->prepare("SELECT * FROM data_member WHERE id_member=?");
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();

// Retrieve data from the query result
if ($user_data = $result->fetch_assoc()) {
    $username = $user_data['username'];
    $jenis_cheat = $user_data['jenis_cheat'];
} else {
    // Handle the case where no user data is found
    echo "User not found!";
    exit();
}

// List of cheat types from the database or predefined options
$cheat_options = [
    '1' => 'Inject Winrate Pragmatic Play',
    '2' => 'Inject Winrate PG Soft',
    '3' => 'Inject Super Wild',
    '4' => 'Inject RTP Maksimal'
];
?>

<html>
<head>
    <title>Edit Username Data Member</title>
    <link rel="stylesheet" href="../style/edit-style.css">
    <meta name="viewport" content="width=device-width, initial-scale=1">
</head>

<body>
    <form name="update_user" method="post" action="edit.php">
        <a href="all-data.php" class="button-link">Home</a>
        <br/><br/>
        <div class="form">
            <div class="title">Edit Data</div>
            <div class="subtitle">Perubahan Pada Data Member</div>

            <!-- Username input field -->
            <div class="input-container ic1">
                <input id="user-id" class="input" type="text" name="username" value="<?php echo htmlspecialchars($username); ?>" placeholder=" " />
                <div class="cut"></div>
                <label for="user-id" class="placeholder">Username</label>
            </div>

            <!-- Jenis Cheat selection -->
            <div class="input-container ic2">
                <select id="jenis-cheat" name="jenis_cheat" class="input">
                    <option value="0" <?php echo ($jenis_cheat == '0') ? 'selected' : ''; ?>>Pilih Jenis Cheat</option>
                    <?php
                    // Loop through cheat options to create dropdown
                    foreach ($cheat_options as $key => $value) {
                        $selected = ($jenis_cheat == $key) ? 'selected' : '';
                        echo "<option value='$key' $selected>$value</option>";
                    }
                    ?>
                </select>
                <div class="cut"></div>
                <label for="jenis-cheat" class="placeholder">Pilih Cheat</label>
            </div>

            <!-- Hidden input for id_member -->
            <div class="input-container ic2">
                <input type="hidden" name="id_member" value="<?php echo htmlspecialchars($_GET['id']); ?>" />
            </div>

            <!-- Update button -->
            <button class="submit" type="submit" name="update" value="Update">UPDATE</button>
        </div>
    </form>
</body>
</html>
